Deserializer

Struct Deserializer 

pub struct Deserializer<'de, S> { /* private fields */ }
Deserialize source into a value.

This is the implementation of serde::de::Deserializer for smallish. If the convenience functions aren’t enough, you can use this directly.

Implementations

Source

impl<'de, S> Deserializer<'de, S>

pub fn new( flavor: Flavor, input: &'de [u8], state: S, unescape: &'de mut [u8], ) -> Self

Create a new flavor-flavored deserializer operating on the given input.

See Parser::new for the meaning of the state argument.

The unescape argument is a scratch buffer where strings and bytes that contain escapes are un-escaped. If this buffer fills completely, deserialization will fail with Error::UnescapeBufferFull. To avoid this, either provide a larger buffer or use Escaped.

It is valid to provide an empty buffer for unescape if you are certain your input will contain no string escapes.

pub fn deserialize<T>(&mut self) -> Result<T, Located<'de, Error>>
where T: Deserialize<'de>,

Deserialize the input into a value.

This is T::deserialize, but it also annotates any errors with their source location and makes sure all input is consumed.